==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/ApplyDestinationAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JonasObjectName;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;
import org.objectweb.jonas.webapp.jonasadmin.deploy.BaseDeployAction;


/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyDestinationAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Form used
        JoramDestinationForm oForm = (JoramDestinationForm) p_Form;
        String idString = (String) m_Session.getAttribute("currentId");
        Integer idInteger = (new Integer(idString));
        int id = idInteger.intValue();

        try {
            ObjectName oObjectName;
            ObjectName joramAdapterON = (ObjectName) JonasManagementRepr.queryNames(JoramObjectName.joramAdapter()).iterator().next();
            if (JonasManagementRepr.isRegistered(joramAdapterON)) {
                oObjectName = joramAdapterON;
            } else {
                oObjectName = JoramObjectName.joramAdmin();
            }

            Object[] asParam = {
                    idInteger, oForm.getName()
            };
            String[] asSignature = {
                    "int", "java.lang.String"
            };
            String type = oForm.getType();
            if (type.equals(m_Resources.getMessage("label.joramplatform.destinations.queue")))
                JonasManagementRepr.invoke(oObjectName, "createQueue", asParam, asSignature);
            else if (type.equals(m_Resources.getMessage("label.joramplatform.destinations.topic")))
                JonasManagementRepr.invoke(oObjectName, "createTopic", asParam, asSignature);

            refreshJoramTree(p_Request, idString);

            oForm.reset(p_Mapping, p_Request);

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Joram Destination"));
    }
}

==> jonas-JONAS_4_10_4.tar.gz: jonas-JONAS_4_10_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/ApplyDestinationAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.Set;

import javax.management.InstanceNotFoundException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.deploy.BaseDeployAction;


/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyDestinationAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Current JOnAS server
        String jonasServerName =  m_WhereAreYou.getCurrentJonasServerName();

        // Form used
        JoramDestinationForm oForm = (JoramDestinationForm) p_Form;
        String idString = (String) m_Session.getAttribute("currentId");
        Integer idInteger = (new Integer(idString));
        int id = idInteger.intValue();
        
        ObjectName oObjectName = null;
        try {
            ObjectName joramAdapterON = JoramObjectName.joramAdapter();
            if (JonasManagementRepr.isRegistered(joramAdapterON, jonasServerName)) {
                oObjectName = joramAdapterON;
            } else {
                //oObjectName = JoramObjectName.joramAdmin();
            	// TODO
            	// Is this situation possible ?
            	// (administrator asks to create a destination when no JoramAdmin MBean available)
            	// ???
            }

            Object[] asParam = {
                    idInteger, oForm.getName()
            };
            String[] asSignature = {
                    "int", "java.lang.String"
            };
            String type = oForm.getType();
            if (type.equals(m_Resources.getMessage("label.joramplatform.destinations.queue"))) {
                JonasManagementRepr.invoke(oObjectName, "createQueue", asParam, asSignature, jonasServerName);
            } else if (type.equals(m_Resources.getMessage("label.joramplatform.destinations.topic"))) {
                JonasManagementRepr.invoke(oObjectName, "createTopic", asParam, asSignature, jonasServerName);
            }
            refreshJoramTree(p_Request, idString);

            oForm.reset(p_Mapping, p_Request);

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Joram Destination"));
    }
}
